---
title: <span class="badge object-type-scalar"></span> GigabitsPerSecond
---
# <span class="badge object-type-scalar"></span> GigabitsPerSecond

Data rate: gigabits/sec

## Definition

```python
# Data rate: gigabits/sec
GigabitsPerSecond: typing.Literal["Gbits"] = "Gbits"
```
